@@ -4,5 +4,6 @@ library(magrittr)
 
 context( "as.character.formula")
 
+test_that( "as.character.formula", {
   as.character( y ~ mx +  b ) %>% expect_identical( "y ~ mx + b" )
-   
\ No newline at end of file
+})
\ No newline at end of file
